summaryrefslogtreecommitdiff
path: root/source3/ubiqx/ubi_sLinkList.h
diff options
context:
space:
mode:
Diffstat (limited to 'source3/ubiqx/ubi_sLinkList.h')
-rw-r--r--source3/ubiqx/ubi_sLinkList.h26
1 files changed, 16 insertions, 10 deletions
diff --git a/source3/ubiqx/ubi_sLinkList.h b/source3/ubiqx/ubi_sLinkList.h
index 1f331cd5b9..53bfa40067 100644
--- a/source3/ubiqx/ubi_sLinkList.h
+++ b/source3/ubiqx/ubi_sLinkList.h
@@ -26,7 +26,13 @@
*
* -------------------------------------------------------------------------- **
*
- * Log: ubi_sLinkList.h,v
+ * Log: ubi_sLinkList.h,v
+ * Revision 0.10 1999/06/19 16:58:06 crh
+ * Renamed the ubi_slRemove() function in ubi_sLinkList to
+ * ubi_slRemoveNext(). I was bothered by the fact that it didn't
+ * match the functionality of the ubi_dlRemove() function in
+ * ubi_dLinkList. The new name is more 'correct'.
+ *
* Revision 0.9 1998/07/24 07:30:20 crh
* Added the ubi_slNewList() macro.
*
@@ -90,9 +96,9 @@
* - In this module, if the list is empty, the tail pointer will
* point back to the head of the list as described above. This
* is not done in ubi_dLinkList.
* - The ubi_slRemove() function, by necessity, removed the 'next'
* node. In ubi_dLinkList, the ubi_dlRemove() function removes
* the 'current' node.
*
* ========================================================================== **
*/
@@ -176,10 +182,10 @@ typedef ubi_slList *ubi_slListPtr;
(ubi_slNodePtr)(N), \
((ubi_slListPtr)(L))->Tail )
-#define ubi_slRemHead( L ) ubi_slRemove( (ubi_slListPtr)(L), NULL )
+#define ubi_slRemHead( L ) ubi_slRemoveNext( (ubi_slListPtr)(L), NULL )
#define ubi_slRemNext( L, N ) \
- ubi_slRemove( (ubi_slListPtr)(L), (ubi_slNodePtr)(N) )
+ ubi_slRemoveNext( (ubi_slListPtr)(L), (ubi_slNodePtr)(N) )
#define ubi_slFirst( L ) (((ubi_slListPtr)(L))->Head)
@@ -228,14 +234,14 @@ ubi_slNodePtr ubi_slInsert( ubi_slListPtr ListPtr,
* ------------------------------------------------------------------------ **
*/
-ubi_slNodePtr ubi_slRemove( ubi_slListPtr ListPtr, ubi_slNodePtr After );
+ubi_slNodePtr ubi_slRemoveNext( ubi_slListPtr ListPtr, ubi_slNodePtr AfterMe );
/* ------------------------------------------------------------------------ **
* Remove the node followng <After>. If <After> is NULL, remove from the
* head of the list.
*
* Input: ListPtr - A pointer to the list from which the node is to be
* removed.
* After - Pointer to the node preceeding the node to be
* removed.
*
* Output: A pointer to the node that was removed, or NULL if the list is
@@ -90,9 +96,9 @@
* point back to the head of the list as described above. This
* is not done in ubi_dLinkList.
- * - The ubi_slRemove() function, by necessity, removed the 'next'
- * node. In ubi_dLinkList, the ubi_dlRemove() function removes
- * the 'current' node.
+ * - The ubi_slRemoveNext() function, by necessity, removes the
+ * 'next' node. In ubi_dLinkList, the ubi_dlRemove() function
+ * removes the 'current' node.
*
* ========================================================================== **
@@ -228,14 +234,14 @@ ubi_slNodePtr ubi_slInsert( ubi_slListPtr ListPtr,
/* ------------------------------------------------------------------------ **
- * Remove the node followng <After>. If <After> is NULL, remove from the
- * head of the list.
+ * Remove the node followng <AfterMe>. If <AfterMe> is NULL, remove from
+ * the head of the list.
*
* Input: ListPtr - A pointer to the list from which the node is to be
@@ -228,14 +234,14 @@ ubi_slNodePtr ubi_slInsert( ubi_slListPtr ListPtr,
* Input: ListPtr - A pointer to the list from which the node is to be
* removed.
- * After - Pointer to the node preceeding the node to be
+ * AfterMe - Pointer to the node preceeding the node to be
* removed.
*